package com.yutu.base.service;

import com.alibaba.fastjson.JSONObject;
import com.yutu.base.utils.HttpsSendData;
import com.yutu.comm.entity.exception.NoteResult;
import org.apache.commons.lang3.StringUtils;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;

/**
 * 销售汇总
 * @author pc
 * @date 2021年03月24日 18:41
 */
@Service
public class SalesSummaryService {

    @Value("${spring.urlConfig.statementApiUrl}")
    private String statementApiUrl;


    private static Logger logger = Logger.getLogger("saleDetail");



    /**
     * 获取销售汇总报表数据
     *      参数：
     *          startCreateOrderTime endCreateOrderTime 生单时间
     *          startTicketTime endTicketTime 出票时间
     *
     * @param requestBody
     * @return
     */
    public NoteResult getSalesSummaryList(String requestBody) {
        NoteResult noteResult = new NoteResult();
        if (StringUtils.isBlank(requestBody)) {
            noteResult.setStatus(300);
            noteResult.setMsg("参数不能为空 [requestBody] ");
            return noteResult;
        }
        logger.info("开始获取数据，参数： " + requestBody);
        long beginTime = System.currentTimeMillis();

        String result = HttpsSendData.getPost(statementApiUrl + "salesSummary/getSalesSummaryList", requestBody);
        // String result = "{\"status\":0,\"msg\":\"查询成功\",\"data\":[{\"id\":\"00027727-2e16-485a-b1b3-f13d5079645a\",\"key\":\"df0286f1-eaac-11e7-adf4-a4badb3682ff_2018-10-25_2018-10-26\",\"createTime\":\"2018-12-21 09:41:41\",\"updateTime\":\"2018-12-21 09:41:41\",\"createOrderTime\":\"2018-10-24 16:24:26\",\"ticketTime\":\"2018-10-25 00:55:41\",\"outerOrderNo\":\"1380889117689\",\"channel\":\"Taobao\",\"store\":\"tbml\",\"tairLine\":\"HKT-DMK\",\"flightTime\":\"1544358000000\",\"flightNumber\":\"FD3028\",\"tripType\":\"单程\",\"pnrType\":\"去程\",\"pnr\":\"BWSTUZ\",\"passengerCount\":1,\"salePrice\":128,\"luggagePrice\":0,\"points\":0,\"purchaseCurrency\":\"CNY\",\"purchasePrice_local\":92,\"purchasePrice_rmb\":92,\"transactionDetail_local\":92,\"transactionDetail_rmb\":92,\"payMethod\":\"支付宝huochepiao3\",\"cardNumber\":\"支付宝huochepiao3\",\"profit\":36,\"transactionNumber\":\" \",\"orderValueAddedNo\":\" \",\"purchaseChannel\":\"艺龙\",\"purchaseAccount\":\"18513092060----huidarui\",\"purchaseOrderNo\":\"IT7JP5181024MO515179\",\"policyType\":\"普通促销\",\"policyCode\":\"TGJ泰国-中国\",\"orderStatus\":\"已出票\",\"operator\":\"曹坤祥\",\"purchaseTime\":\"2018-10-24 19:01:39\",\"orderValueAdded\":\" \",\"orderValueAddedSpecific\":\" \",\"remark\":\" \",\"officalReceivedPaymentStatus\":\" \",\"officalActualExpendAmount\":0,\"officalBalance\":0,\"officalRateAdjustDate\":null,\"passengerNames\":null,\"adultCount\":1,\"childCount\":0,\"sortIndex\":438}],\"info\":null}";

        if (StringUtils.isBlank(result)) {
            noteResult.setStatus(300);
            noteResult.setMsg("获取数据失败!");
            noteResult.setData(new HashMap<String, String>());
            return noteResult;
        }
        JSONObject resultObj = JSONObject.parseObject(result);
        if (resultObj.getInteger("status") != 200) {
            noteResult.setMsg("获取数据失败!");
            return noteResult;
        }
        logger.info("获取数据成功，共用时：" + (System.currentTimeMillis() - beginTime));
        return  JSONObject.toJavaObject(resultObj, NoteResult.class);
    }
}
